@@ -1,9 +1,15 @@
 from aiohttp import ClientSession
 
 from .accounts import AccountsAPI
+from .blocks import BlocksAPI
+from .bookmarks import BookmarksAPI
 from .conversations import ConversationsAPI
+from .domain_blocks import DomainBlocksAPI
+from .favourites import FavouritesAPI
+from .filters import FiltersAPI
 from .instance import InstanceAPI
 from .lists import ListsAPI
+from .mutes import MutesAPI
 from .notifications import NotificationsAPI
 from .statuses import StatusesAPI
 from .timelines import TimelinesAPI
@@ -21,9 +27,15 @@ class MastodonAPI:
         self.ssl = ssl
         self.session = ClientSession()
         self.accounts = AccountsAPI(self)
+        self.blocks = BlocksAPI(self)
+        self.bookmarks = BookmarksAPI(self)
         self.conversations = ConversationsAPI(self)
+        self.domain_blocks = DomainBlocksAPI(self)
+        self.favourites = FavouritesAPI(self)
+        self.filters = FiltersAPI(self)
         self.instance = InstanceAPI(self)
         self.lists = ListsAPI(self)
+        self.mutes = MutesAPI(self)
         self.notifications = NotificationsAPI(self)
         self.statuses = StatusesAPI(self)
         self.timelines = TimelinesAPI(self)
